---
title: "Hypothesis Testing"
author: "Peter Putz"
date: "September 19, 2014"
output: 
  rmarkdown::tufte_handout:
        highlight: tango
---



\newthought{The purpose of this paper}[^coursera] is to to analyze the ToothGrowth
data in the R datasets package. 

\newthought{The dataset}[^data] is the result of a study on "The Effect of 
Vitamin C on Tooth Growth in Guinea Pigs. The response is the length of 
odontoblasts (teeth) in each of 10 guinea pigs at each of three dose levels of 
Vitamin C (0.5, 1, and 2 mg) with each of two delivery methods 
(orange juice or ascorbic acid)."


```{r load, echo=FALSE, results='hide'}
library(datasets)
data(ToothGrowth)

str(ToothGrowth)
```


```{r explor, fig.width = 6, fig.height = 5.2, dev='tikz', echo=FALSE, fig.cap = "Tooth Lengths by Vitamine C Dose and Delivery Method"}
library(ggplot2)
ggplot(ToothGrowth, aes(x = dose, y = len)) +
    geom_point(size = 3, colour="grey30", shape = 1) +
    scale_shape(solid = FALSE) +
    stat_summary(fun.y=mean, geom="line", colour = "red") +
    facet_grid(. ~ supp) +
    theme_bw(base_size = 14)
```

```{r summarize, comment=NA, results='asis', message=FALSE, echo=FALSE}
library(dplyr)
library(xtable)
treatm <- group_by(ToothGrowth, supp, dose)
growth <- summarize(treatm, 
                    count = n(),
                    mean = mean(len),
                    var = var(len))
print(xtable(growth, 
             caption = "Summary of Treatment Groups"), 
      comment=FALSE)
```

\newthought{Summarizing our brief exploratory analysis}, I found no extreme
outliers or missing values. Figure 1 and the means in table 1 suggest the
following hypotheses to be further explored:

1. Increased levels of vitamine C lead to longer teeth for delivery method "orange juice".
2. Increased levels of vitamine C lead to longer teeth for delivery method "ascorbic acid".
3. For a dose of 2.0 mg there is no difference in tooth length between the two delivery methods.


\newthought{To test the above hypotheses} I perform a set of 2-sample t-tests
and choose a confidence intervall of $(1-\alpha) = 0.95$. For all comparisons the
null hypothesis is $H_0: \mu_1 - \mu_2 = 0$. Since the details of the study design
are unknown, I assume that the population variances are not equal. I also
assume that the treatment groups are independend.

To control for false positives due to multiple testing I choose the Bonferroni correction, 
since it is the most conservative approach.

```{r ttest, comment=NA, results='asis', message=FALSE, echo=FALSE}
ToothGrowth$group <- paste(ToothGrowth$supp, format(ToothGrowth$dose, nsmall=1), sep = "")
p <- pairwise.t.test(x = ToothGrowth$len, g = ToothGrowth$group, 
                p.adjust.method = "bonferroni", pool.sd = FALSE, paired = FALSE, 
                alternative = "two.sided")
print(xtable(p$p.value, digits = 5,  
             caption = "2-Sample t-Tests With Separate Variances and Bonferroni Adjusted p-Values"), 
      comment=FALSE, floating = TRUE)
```

\vspace{5 mm}
\noindent Based on the chosen significance level $\alpha = 0.05$ I reject all null-hypotheses
with an adjusted p-value < 0.05:

Hypothesis 1: OJ0.5 vs. OJ2.0 -- $H_0$ rejected  
Hypothesis 2: VC0.5 vs. VC2.0 -- $H_0$ rejected  
Hypothesis 3: OJ2.0 vs. VC2.0 -- $H_0$ not rejected

\newthought{Conclusions.} Based on the results of the t-Tests in table 2 all three 
hypotheses could be confirmed.

This assumes that the treatment groups are randomly selected and the measurements
are independent. 


\pagebreak


# Appendix

## Souce code for Figure 1[^sorry]

```{r explor, eval=FALSE, tidy=TRUE, tidy.opts=list(keep.blank.line=FALSE, width.cutoff=60)}
```

## Souce code for Table 1

```{r summarize, eval=FALSE}
```

## Souce code for Table 2

```{r ttest, eval=FALSE, tidy=TRUE, tidy.opts=list(keep.blank.line=FALSE, width.cutoff=60)}
```

## Session Info

```{r sessioninfo, size='footnotesize'}
sessionInfo()
```

[^coursera]: This paper is in reponse to a peer assignment of the Coursera course "Statistical Inference" by Brian Caffo, Jeff Leek, and Roger Peng.
[^data]: See documentation of 'datasets' package. The ‘datasets’ package is part of R: R Core Team (2014). R: A language and environment for statistical computing. R Foundation for Statistical Computing,
  Vienna, Austria. URL http://www.R-project.org/.
[^sorry]: Appologies for the poor code formating. This seems to be a bug with
the Tufte template in RStudio.